"use client";
import React, { useState } from "react";
import { FaFileContract } from "react-icons/fa6";
import { addDays, format } from "date-fns";
import { Calendar as CalendarIcon, Router } from "lucide-react";

import { cn } from "@/lib/utils";
import { Button } from "@/components/ui/button";
import { Calendar } from "@/components/ui/calendar";
import {
	Popover,
	PopoverContent,
	PopoverTrigger,
} from "@/components/ui/popover";
import { useRouter } from "next/navigation";

const VisaInfoCard = () => {
	const [travelerNo, setTravelerNo] = useState(1);
	const [date, setDate] = useState<Date>();
	const [price, setPrice] = useState(11753);
	const router = useRouter();

	const handleIncrement = () => {
		setTravelerNo((prevCount) => prevCount + 1);
	};

	const handleDecrement = () => {
		if (travelerNo > 1) {
			setTravelerNo((prevCount) => prevCount - 1);
		}
	};

	const handleStartApplicationDate = () => {
		router.push("/obj");
	};

	return (
		<div className="md:w-[40%] xl:w-[35%] mx-auto  bg-white rounded-xl shadow-2xl overflow-hidden">
			<div className="justify-center bg-teal-600 text-white px-4 py-6 drop-shadow-lg flex items-center">
				<svg
					className="w-6 h-6 mr-2"
					fill="none"
					stroke="currentColor"
					viewBox="0 0 24 24"
					xmlns="http://www.w3.org/2000/svg"
				>
					<path
						strokeLinecap="round"
						strokeLinejoin="round"
						strokeWidth={2}
						d="M9 12l2 2 4-4m6 2a9 9 0 11-18 0 9 9 0 0118 0z"
					/>
				</svg>
				<div>
					<div className="text-sm">Visa guaranteed on</div>
					<div>9 Aug 2024 at 09:00 PM</div>
				</div>
			</div>

			<div className="px-4 py-6">
				<div className="flex items-center justify-between mb-4">
					<div className="flex items-center">
						<svg
							className="w-6 h-6 mr-2"
							fill="none"
							stroke="currentColor"
							viewBox="0 0 24 24"
							xmlns="http://www.w3.org/2000/svg"
						>
							<path
								strokeLinecap="round"
								strokeLinejoin="round"
								strokeWidth={2}
								d="M12 4.354a4 4 0 110 5.292M15 21H3v-1a6 6 0 0112 0v1zm0 0h6v-1a6 6 0 00-9-5.197M13 7a4 4 0 11-8 0 4 4 0 018 0z"
							/>
						</svg>
						<span>Travelers</span>
					</div>
					<div className="flex items-center">
						<button
							className="px-3 py-1 font-semibold bg-gray-200 rounded-l"
							onClick={handleDecrement}
						>
							-
						</button>
						<span className="w-10 text-center">{travelerNo}</span>
						<button
							className="px-3 py-1 font-semibold bg-gray-200 rounded-r"
							onClick={handleIncrement}
						>
							+
						</button>
					</div>
				</div>
				<div className="border-b border-gray-300 -mt-2 mb-4"></div>

				<div className="mb-4 mt-8">
					<h3 className="font-bold mb-2 text-lg">Price</h3>
					<div className="flex justify-between mb-2">
						<div className="flex space-x-2">
							<FaFileContract size={20} />
							<span className="underline">Visa Fees</span>
						</div>
						<span>
							BDT {price} x {travelerNo}
						</span>
					</div>
					<div className="w-full flex justify-between font-semibold text-lg mt-4">
						<span>Total</span>
						<span>BDT {price * travelerNo}</span>
					</div>
				</div>

				<Popover>
					<PopoverTrigger asChild>
						<Button
							variant={"outline"}
							className={cn(
								"w-full flex justify-start text-left font-normal",
								!date && "text-muted-foreground",
							)}
						>
							<CalendarIcon className="mr-2 h-4 w-4" />
							{date ? (
								<span>{format(date, "PPP")}</span>
							) : (
								<span>Pick travel date</span>
							)}
						</Button>
					</PopoverTrigger>
					<PopoverContent className="p-0">
						<Calendar
							mode="single"
							selected={date}
							onSelect={setDate}
							initialFocus
							defaultMonth={addDays(new Date(), 29)}
							disabled={(date) => date < addDays(new Date(), 29)}
						/>
					</PopoverContent>
				</Popover>

				<button
					onClick={handleStartApplicationDate}
					className="w-full mt-6 bg-teal-600 text-white py-2 rounded-xl"
				>
					Start Application
				</button>
			</div>
		</div>
	);
};

export default VisaInfoCard;
